/* options.h
 *
 * Copyright (c) 1999 Chris Smith
 *
 * This file is distributed under the GPL, version 2 or at your option any
 * later version.  See COPYING for details.
 */

#ifndef LPE_OPTIONS_H
#define LPE_OPTIONS_H

#include "config.h"

#ifdef HAVE_LIMITS_H
#define LIMITS_H "limits.h"
#elif defined(HAVE_SYS_SYSLIMITS_H)
#define LIMITS_H "sys/syslimits.h"
#endif

/* Configurable Options ******************************************************/

/* Flash Brace: This option causes the cursor position to flash briefly to the
 * beginning of a properly nested set of parentheses, braces, etc., to indicate
 * the current level of nesting visually.
 *
 * Default:      ON
 *
 * Parameters:
 *      FLASH_TIME: The time, in tenths of a second to flash the cursor to a
 * matching brace if one is found.
 */
/* #define OPT_FLASH_BRACE
#define FLASH_TIME 3 */

/* Syntax Highlighting: This option results in use of ANSI color, if available,
 * to color text according to its lexical meaning.  For example, in C, keywords
 * will appear in cyan, identifiers in light gray, and comments in green.
 *
 * Default:      OFF
 */
/* #define OPT_SYNTAX_HIGHLIGHTING */

/* Auto Indentation: This option enable automatic indentation of new lines of
 * text, so that when ENTER is pressed, an appropriate is inferred from the
 * surrounding text.  If a mode is selected that support automatic indentation,
 * then indentation is tailored to the language selected.
 *
 * Default:      ON
 *
 * Parameters:
 *      MAX_INDENT_LEVEL: Used in cmode's extended indent scheme -- it decides
 * the maximum possible indent level of a C program.
 */
/* #define OPT_AUTO_INDENT */
#define MAX_INDENT_LEVEL      10

/* Macro Recorder: This option allows recording a set of keystrokes and playing
 * them back with a single key.  In conjunction with the command repeater, it
 * provides an easy way of automating tasks that are too simple to bother with
 * sed or awk.
 *
 * Default:      OFF
 * Dependencies: none
 *
 * Parameters:
 *      MAX_MACRO_KEYS: The maximum number of keystrokes that can fit in a
 * recorded macro.  Trying to record more causes a warning and discards the
 * recording.
 *      MAX_MACRO_ANSWER_LEN: The size of a buffer to hold answers to minibuf
 * questions asked while recording a macro.  This is used so that the user is
 * not interactively re-asked the questions when replaying macros.
 */
/* #define OPT_MACRO_RECORDER */
#define MAX_MACRO_KEYS       1024
#define MAX_MACRO_ANSWER_LEN 1024

/* Stream Manipulation: This option provides for manipulating a buffer as a
 * stream by passing it through a variety of external stream-oriented commands
 * such as sed, awk, or Bourne shell scripts.
 *
 * Default:      OFF
 * Dependencies: none
 *
 * Parameters:
 *      CMD_SH: The name of a Bourne (or compatible) shell
 *      CMD_AWK: The name of an awk script interpreter
 *      CMD_SED: The name of a sed script interpreter
 */
/* #define OPT_STREAM_MANIP */
#define CMD_SH  "sh"
#define CMD_AWK "awk"
#define CMD_SED "sed"

/* Configurable Parameters ***************************************************/

/* The granularity with which storage is reallocated.  Make this value smaller
 * for a slower editor that uses less memory.  Make it bigger for a faster
 * editor that uses more memory.
 */
#define REALLOC_GRAN 10

/* The scrolling granularity.  This can be changed on systems that will be used
 * frequently over a terminal.  A value of zero (default) indicates normal
 * scrolling, and each number above that is an additional row or column to
 * "jump."  Note that this value should be less than the expected terminal
 * dimension (in either direction) or unpredictable behavior could result.
 */
#define SCROLL_GRAN 0

/* Tab widths.  Changing these changes how tabs are inserted in lpe (although,
 * of course, changing HARD_TAB_WIDTH will not change how the resulting tabs
 * look in other programs, so it's not recommended.
 */
#define SOFT_TAB_WIDTH 4
#define HARD_TAB_WIDTH 8

/* The default place to look for modules.  This can be overridden by the
 * LPE_MODULE_PATH environment variable.  For now, it looks first for modules
 * installed by the user, then for site local modules in /usr/local, then for
 * standard modules in /usr, and finally, if none of the others are found, in
 * the old location; /etc/lpe.
 */
/* #define DEF_MODULE_PATH "~/.lpe:/usr/local/lib/lpe:/usr/lib/lpe:/etc/lpe" */

#endif /* LPE_OPTIONS_H */
